# Data Catalog

> see https://aka.ms/autorest

This is the AutoRest configuration file for Data Catalog.



---
## Getting Started
To build the SDK for Data Catalog, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration


### Basic Information
These are the global settings for the Data Catalog API.

``` yaml
title: DataCatalogRestClient
description: The Azure Data Catalog management API provides a RESTful set of web services that interact with Azure Data Catalog services.
openapi-type: arm
tag: package-2016-03-30
```

### Tag: package-2016-03-30

These settings apply only when `--tag=package-2016-03-30` is specified on the command line.

``` yaml $(tag) == 'package-2016-03-30'
input-file:
- Microsoft.DataCatalog/stable/2016-03-30/datacatalog.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DataCatalog
  output-folder: $(csharp-sdks-folder)/DataCatalog/Management.DataCatalog/Generated
  clear-output-folder: true
```

# Validation

## Suppression

``` yaml
directive:
  - suppress: R3018  # EnumInsteadOfBoolean
    where: 
      - $.definitions.ADCCatalogProperties.properties.successfullyProvisioned
      - $.definitions.ADCCatalogProperties.properties.enableAutomaticUnitAdjustment
    from: datacatalog.json
    reason: Booleans are used to indicate binary states of the property, enum is not appropriate.
  - suppress: R3027  # TrackedResourceListByResourceGroup
    where: 
      - $.definitions.ADCCatalog
    from: datacatalog.json
    reason: Catalog is per tenant level resources.
  - suppress: R3028  # TrackedResourceListBySubscription
    where: 
      - $.definitions.ADCCatalog
    from: datacatalog.json
    reason: Catalog can only be listed by resource group.
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  clear-output-folder: true
  namespace: datacatalog
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2016-03-30
```

### Tag: package-2016-03-30 and go

These settings apply only when `--tag=package-2016-03-30 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='package-2016-03-30' && $(go)
output-folder: $(go-sdk-folder)/services/datacatalog/mgmt/2016-03-30/datacatalog
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.datacatalog
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-datacatalog
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2016-03-30
```

### Tag: package-2016-03-30 and java

These settings apply only when `--tag=package-2016-03-30 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-03-30' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.datacatalog.v2016_03_30
  output-folder: $(azure-libraries-for-java-folder)/datacatalog/resource-manager/v2016_03_30
regenerate-manager: true
generate-interface: true
```


